@@ -21,3 +21,9 @@ def is_included(pathname, options):
         return False
     
     return True
+
+def safe_get(member, key):
+    try:
+        return member.get(key, None)
+    except:
+        return None
